==> aroundme_0_5_2.zip: aroundme_0_5_2/aroundme/language/1/barnraiser_01/mag_item.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'mag_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/

//SECTION
$lang['section_blog'] = 						"blog";
$lang['section_subject'] = 						"subject";
$lang['section_poll'] = 						"poll";
$lang['section_library_item'] = 				"library item";
$lang['section_add_comment'] = 					"add comment";
$lang['hdr_vote_history'] =						"vote history";
$lang['hdr_my_vote_history'] =					"my vote history";
$lang['hdr_comment_preview'] = 					"comment preview";
$lang['hdr_comments'] = 						"comments";
$lang['hdr_tag'] = 								"tags";


//ERRORS
$lang['err_no_comments'] = 						"Sorry, no comments available.";


//SUB
$lang['sub_vote'] = 							"vote";
$lang['sub_add'] = 								"add";
$lang['sub_edit_again'] = 						"edit again";
$lang['sub_preview'] = 							"preview";
$lang['sub_save'] = 							"save";
$lang['sub_vote_change'] = 						"change vote";


//TXT
$lang['txt_comment_datetime'] =					"Comment date and time";
$lang['txt_comment_help'] = 					"Remember to observe the rules of the community.";
$lang['txt_no_comment_allowed'] = 				"Sorry, this item is not open to receive your comments.";
$lang['txt_poll_required'] =					"you are required to vote before seeing comments.";
$lang['txt_anonymous'] =						"anonymous";
$lang['txt_last_edit'] = 						"last edited";
$lang['txt_joined'] = 							"joined";
$lang['txt_hometown'] = 						"home town";
$lang['txt_group'] = 							"group";
$lang['txt_tag_item'] = 						"This community has tagged this item with";

?>

==> aroundme_0_5_3.zip: aroundme_0_5_3/aroundme/language/1/barnraiser_01/mag_item.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'mag_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/

//SECTION
$lang['section_blog'] = 						"blog";
$lang['section_subject'] = 						"subject";
$lang['section_poll'] = 						"poll";
$lang['section_library_item'] = 				"library item";
$lang['section_add_comment'] = 					"add comment";
$lang['hdr_vote_history'] =						"vote history";
$lang['hdr_my_vote_history'] =					"my vote history";
$lang['hdr_comment_preview'] = 					"comment preview";
$lang['hdr_comments'] = 						"comments";
$lang['hdr_tag'] = 								"tags";


//ERRORS
$lang['err_no_comments'] = 						"Sorry, no comments available.";


// HREF
$lang['href_item_comments_only'] = 				"Show only the comment against this version of this page";
$lang['href_all_comments'] = 					"Show all comments associated with this page";


//SUB
$lang['sub_vote'] = 							"vote";
$lang['sub_add'] = 								"add";
$lang['sub_edit_again'] = 						"edit again";
$lang['sub_preview'] = 							"preview";
$lang['sub_save'] = 							"save";
$lang['sub_vote_change'] = 						"change vote";


//TXT
$lang['txt_comment_datetime'] =					"Comment date and time";
$lang['txt_comment_help'] = 					"Remember to observe the rules of the community.";
$lang['txt_no_comment_allowed'] = 				"Sorry, this item is not open to receive your comments.";
$lang['txt_poll_required'] =					"you are required to vote before seeing comments.";
$lang['txt_anonymous'] =						"anonymous";
$lang['txt_last_edit'] = 						"last edited";
$lang['txt_joined'] = 							"joined";
$lang['txt_hometown'] = 						"home town";
$lang['txt_group'] = 							"group";
$lang['txt_tag_item'] = 						"This community has tagged this item with";

?>
